#!/usr/bin/Rscript

source("../lib/curve.r")
source("../lib/stats.r")
source("../lib/util.r")
source("../lib/eia.r")

# There are several different plot we can make.
types <- c("Total Energy", "Biofuel", "Petroleum", "Coal", "Natural Gas")
titles <- paste(types, "Consumption")
files <- paste0("../data/", types, " Use.csv")

# 2012 data is included in these data files, but of course it also is not very
# good. Exclude both 2011 and 2012.
read.eia <- function (n) {
	raw <- read.csv(n)
	rownames(raw) <- raw$Region
	return(raw[!(raw$Region %in% exclude),][!(names(raw) %in% c("Region", "X2012", "X2011"))])
}

pop <- read.eia("../data/Population.csv")
dats <- Vectorize(read.eia)(files)
names(dats) <- types

# Routine to plot a gini object with points().
plot.gini.points <- function (dat, col, pch) {
	years <- as.numeric(substring(Filter(function (x) substr(x, 1, 1) == "X",
					     names(dat)), 2))

	g <- c()
	for (n in names(dat)) {
		year <- as.numeric(substring(n, 2))
		ydat <- setNames(dat[,n], rownames(n))
		ypop <- pop[,n]
		not.na <- !is.na(ydat) & !is.na(ypop)
		ydat <- ydat[not.na]
		ypop <- ypop[not.na]
		l <- Lorenz(ydat / ypop, ypop)
		g <- c(g, Gini(l))
	}
	points(years, g, col=col, pch=pch)
}

# Write intermediate data file.
years <- seq(1980, 2010)
sel <- types %in% c("Coal", "Natural Gas", "Petroleum")
data <- data.frame(years, row.names=1)
newdat <- sapply(dats[sel], function (dat) {
	g <- c()
	for (n in names(dat)) {
		year <- as.numeric(substring(n, 2))
		ydat <- setNames(dat[,n], rownames(n))
		ypop <- pop[,n]
		not.na <- !is.na(ydat) & !is.na(ypop)
		ydat <- ydat[not.na]
		ypop <- ypop[not.na]
		l <- Lorenz(ydat / ypop, ypop)
		g <- c(g, Gini(l))
	}
	g
})
data[c("Coal", "Natural Gas", "Petroleum")] <- newdat
write.csv(data, "Figure 8.csv")

# Begin plotting
pdf("Figure 8.pdf")
plot.new()
par(mar=c(4.2, 4.2, 3, 0.4))
box()
plot.window(c(1980, 2010), c(0.5, 0.82))

title(main="Gini Coefficients of Energy Consumption by Source",
      xlab="Year", cex.main=1.5, cex.lab=1.4, font.main=1,
      ylab="Gini Coefficient")
text(1980, 0.5, "Data source: EIA", adj=c(0, 0.5), cex=1.4, font=1)

text(2000, 0.6, "Petroleum", adj=c(1, 1), cex=1.4, font=1, col="#0000dd")
text(2005, 0.78, "Natural gas", adj=c(1, 0), cex=1.4, font=1, col="#dd0000")
text(2000, 0.67, "Coal", adj=c(1, 1), cex=1.4, font=1, col="#000000")

axis(side=2, at=seq(0, 1, 0.01), labels=F)
axis(side=2, at=seq(0.5, 1, 0.05), labels=T, tck=-0.03)
axis(side=1, at=seq(1980, 2010), labels=F)
axis(side=1, at=seq(1980, 2010, 5), labels=T, tck=-0.03)

# Overlay coal, petroleum, and gas
mapply(plot.gini.points, dats[sel], c("#000000", "#0000dd", "#dd0000"), c(15, 16, 17))
