%This script generates 31 frames of high resolution movie of  CO_2 emission Lorenz curves%
%Making movie files need call ffmpegtranscode() in MATLAB. Examples can be
%found in ffmpegtranscode.m in ffmpeg toolbox.%
%Codes in this file are parallel to EnergyConsumptionLorenzMov.m%

%Author: Qin Liu%

%read data%
%read global CO_2 emission, population and  CO_2 emission per
%capita.%
ce_mov=csvread('TotalCO2',0,0,[3,1,224,34]);%CO_2 emission%
pop_mov=csvread('Global_pop',0,0,[3,3,226,34]);%population%
cepercap_mov=csvread('cepercap',0,0,[3,3,226,34]);%emission per capita%
format long;

%Calculate cumulative data for population and emission for 32 years from
%1980 to 2011. In current movie, year 2011 is not included.%
for j=1:32;
    ce=ce_mov(:,j);
pop=pop_mov(:,j);
cepercap=cepercap_mov(:,j);
data=[cepercap,ce,pop];
lorentz=sortrows(data,1);%sort data by emission per capita%
s_ce=lorentz(:,2);
s_pop=lorentz(:,3);
ceratio(:,j)=s_ce/sum(s_ce);
popratio(:,j)=s_pop/sum(s_pop);
for i=1:224;
    cm_ceratio(i,j)=sum(ceratio(1:i,j:j));
end

for i=1:224;
    cm_popratio(i,j)=sum(popratio(1:i,j:j));
end
end

for j=1:11;
    x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on
plot(cm_popratio(:,j),cm_ceratio(:,j),'r.-');
hold on
highlitx1=[cm_popratio(86,1),cm_popratio(127,1),cm_popratio(130,1),cm_popratio(188,1),cm_popratio(195,1),cm_popratio(197,1),cm_popratio(214,1)];
highlity1=[cm_ceratio(86,1),cm_ceratio(127,1),cm_ceratio(130,1),cm_ceratio(188,1),cm_ceratio(195,1),cm_ceratio(197,1),cm_ceratio(214,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;
%add timer%
year=1979+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');
%labels, title and legend%
%positions are already well-adjusted%
t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.85,.38,'UK');
t18=text(.83,.31,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.915,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');
t=title('Lorenz Plot of Global CO_{2} Emission');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World CO_{2} Emission');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.64',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j));
end

for j=1:10;
  x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on

plot(cm_popratio(:,j+11),cm_ceratio(:,j+11),'r.-');
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on

highlitx1=[cm_popratio(86,1),cm_popratio(127,1),cm_popratio(130,1),cm_popratio(188,1),cm_popratio(195,1),cm_popratio(197,1),cm_popratio(214,1)];
highlity1=[cm_ceratio(86,1),cm_ceratio(127,1),cm_ceratio(130,1),cm_ceratio(188,1),cm_ceratio(195,1),cm_ceratio(197,1),cm_ceratio(214,1)];

plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;
year=1990+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');

t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.85,.38,'UK');
t18=text(.83,.31,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.915,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');


t=title('Lorenz Plot of Global CO_{2} Emission');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World CO_{2} Emission');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.64','1990 G=0.62',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j+11));
end

for j=1:9;
   x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on
plot(cm_popratio(:,21),cm_ceratio(:,21),'.-','Color',[0 .4 .3]);
hold on
plot(cm_popratio(:,j+21),cm_ceratio(:,j+21),'r.-');
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on

highlitx1=[cm_popratio(86,1),cm_popratio(127,1),cm_popratio(130,1),cm_popratio(188,1),cm_popratio(195,1),cm_popratio(197,1),cm_popratio(214,1)];
highlity1=[cm_ceratio(86,1),cm_ceratio(127,1),cm_ceratio(130,1),cm_ceratio(188,1),cm_ceratio(195,1),cm_ceratio(197,1),cm_ceratio(214,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;
year=2000+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');

t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.85,.38,'UK');
t18=text(.83,.31,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.915,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');
t=title('Lorenz Plot of Global CO_{2} Emission');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World CO_{2} Emission');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.64','1990 G=0.62','2000 G=0.58',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j+21));   
end

j=31;
x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);


hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on
plot(cm_popratio(:,21),cm_ceratio(:,21),'.-','Color',[0 .4 .3]);
hold on
plot(cm_popratio(:,31),cm_ceratio(:,31),'r.-');
hold on


plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on

highlitx1=[cm_popratio(86,1),cm_popratio(127,1),cm_popratio(130,1),cm_popratio(188,1),cm_popratio(195,1),cm_popratio(197,1),cm_popratio(214,1)];
highlity1=[cm_ceratio(86,1),cm_ceratio(127,1),cm_ceratio(130,1),cm_ceratio(188,1),cm_ceratio(195,1),cm_ceratio(197,1),cm_ceratio(214,1)];

plot(highlitx1,highlity1,'b.','Markersize',25);
hold on

highlitx32=[cm_popratio(79,31),cm_popratio(101,31),cm_popratio(151,31),cm_popratio(152,31),cm_popratio(174,31),cm_popratio(194,31),cm_popratio(210,31)];
highlity32=[cm_ceratio(79,31),cm_ceratio(101,31),cm_ceratio(151,31),cm_ceratio(152,31),cm_ceratio(174,31),cm_ceratio(194,31),cm_ceratio(210,31)];
plot(highlitx32,highlity32,'r.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;

t6=text(0.03,0.6,'Data source: EIA');
t7=text(.84,.95,'USA');
t8=text(.665,.47,'CHN');
t9=text(.80,.72,'RUS');
t10=text(.44,.21,'FRA');
t11=text(.75,.54,'UK');
t12=text(.365,.15,'BRA');
t13=text(.3,.10,'IND');
t14=text(.22,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.85,.38,'UK');
t18=text(.83,.31,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.915,0.57,'USSR');
set(t6,'Fontsize',15);
set(t7,'Fontsize',16,'Color','r');
set(t8,'Fontsize',16,'Color','r');
set(t9,'Fontsize',16,'Color','r');
set(t10,'Fontsize',16,'Color','r');
set(t11,'Fontsize',16,'Color','r');
set(t12,'Fontsize',16,'Color','r');
set(t13,'Fontsize',16,'Color','r');


set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');


t=title('Lorenz Plot of Global CO_{2} Emission');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World CO_{2} Emission');
year=1979+j;
timer=text(0.3,0.24,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.64','1990 G=0.62','2000 G=0.58','2010 G=0.52',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(31));   